@@ -552,6 +552,14 @@ class postprocess:
             
             | Veg_ID (integer) -- the vegetation ID  in the vegetation polygon,-1 for lake
             | VEG_C (string) -- the vegetation class name for each vegetation Type
+        projected_epsg_code                     : string (optional)
+            is a EPSG code to indicate a projected coordinate system. 
+            If the routing network generated by basinmaker is under a 
+            projected system, please assgin the EPSG code of that projected 
+            system to projected_epsg_code. If the routing network generated by 
+            basinmaker is under a geographic system, please use EPSG code from 
+            any projected system. The coordinate system of routing network from
+            basinmaker is determined by the coordinate system  of input DEM.
         path_connect_lake_polygon            : string (Optional)
             is the path to the connected lake's polygon
         path_non_connect_lake_polygon        : string (Optional)
@@ -1063,7 +1071,13 @@ class delineate:
         path_output_folder                  : string
             The path to a folder to save outputs
         projected_epsg_code                     : string (optional)
-            is a EPSG code to indicate a projected coordinate system  
+            is a EPSG code to indicate a projected coordinate system. 
+            If the routing network generated by basinmaker is under a 
+            projected system, please assgin the EPSG code of that projected 
+            system to projected_epsg_code. If the routing network generated by 
+            basinmaker is under a geographic system, please use EPSG code from 
+            any projected system. The coordinate system of routing network from
+            basinmaker is determined by the coordinate system  of input DEM.         
         path_bkfwidthdepth_polyline             : string (optional)
             is a path of the polyline shapefile that contains bankfull width (w) and
             depth (d) data.Following the methodology in Andreadis et al. (2013), 
